#ifndef _DAHDI_TDMOX_H
#define _DAHDI_TDMOX_H

struct dahdi_tdmox_span {
	char driver[20];	/* Which low-level driver to use */
	char addr[40];		/* Destination address */
	int numchans;		/* Number of channels */
	int timing;		/* Timing source preference */
	int spanno;		/* Span number (filled in by DAHDI) */
	int span_id_sysfs;	/* Pavel. Will remove that struct later. */
};

struct dahdi_tdmox {
	char addr[40];
	char dname[20];
	int err;
	struct kref kref;
	long rxjif;
	unsigned short txcnt;
	unsigned short rxcnt;
	struct dahdi_device *ddev;
	struct dahdi_span span;
	struct dahdi_chan *chans[256];
	struct dahdi_tdmox_driver *driver;
	void *pvt;
	int timing;
	int master;
	unsigned char *msgbuf;
	struct device *dev;
	struct kfifo *rxfifo;
	int rxfifo_size;        /* Not aligned size of FIFO, we actually use */
	spinlock_t rxfifo_lock; /* See connent below (spin_lock_init) */
	unsigned int slip;
	unsigned int skip;
	unsigned int rxnuerr;

	struct list_head list;
};

struct dahdi_tdmox_driver {
	/*! Driver name (e.g. Eth) */
	const char *name;

	/*! Driver description */
	const char *desc;

	/*! Create a new transmission pipe */
	int (*create)(struct dahdi_tdmox *d, const char *address);

	/*! Destroy a created transmission pipe */
	void (*destroy)(struct dahdi_tdmox *d);

	/*! Transmit a given message */
	void (*transmit)(struct dahdi_tdmox *d, u8 *msg, size_t msglen);

	/*! Flush any pending messages */
	int (*flush)(void);

	struct list_head list;
	struct module *owner;

	/*! Numberic id of next device created by this driver. */
	unsigned int id;
};

struct dahdi_tdmox_ops {
	struct module *owner;
	int (*ioctl)(unsigned int cmd, unsigned long data);
};

int dahdi_tdmox_register_driver(struct dahdi_tdmox_driver *);
void dahdi_tdmox_unregister_driver(struct dahdi_tdmox_driver *);
void dahdi_tdmox_receive(struct dahdi_span *, unsigned char *, int);
int dahdi_tdmox_create(struct dahdi_tdmox_span *);
int dahdi_tdmox_destroy(struct dahdi_tdmox_span *);

#endif /* _DAHDI_TDMOX_H */
